@@ -9,8 +9,8 @@
 #' 
 #' @concept yac_symbol
 #' @export
-yac_symbol <- function(x) {
-  # TODO: Consider NSE: e.g. yac_symbol(4*x + 5*y) directly?
+ysym <- function(x) {
+  # TODO: Consider NSE: e.g. ysym(4*x + 5*y) directly?
   
   stopifnot(is.vector(x) | is.matrix(x))
   
@@ -35,6 +35,21 @@ yac_symbol <- function(x) {
   return(y)
 }
 
+#' Make a yacas symbol
+#' 
+#' This is an alias for [ysym()]. 
+#' See description there.
+#' 
+#' @param x A vector or a matrix
+#' 
+#' @return A `yac_symbol`
+#' 
+#' @concept yac_symbol
+#' @export
+yac_symbol <- function(x) {
+  return(ysym(x)) 
+}
+
 # S3 exports
 
 #' @export
@@ -66,10 +81,15 @@ yac_assign.yac_symbol <- function(value, x) {
 y_fn.yac_symbol <- function(x, fn, ...) {
   x <- y_fn(x$yacas_cmd, fn, ...)
   y <- yac_str(x)
-  z <- yac_symbol(y)
+  z <- ysym(y)
   return(z)
 }
 
+#' @export
+as_y.yac_symbol <- function(x) {
+  return(x$yacas_cmd)
+}
+
 #' @export
 as_r.yac_symbol <- function(x) {
   y <- yac_expr(x$yacas_cmd)
@@ -99,7 +119,8 @@ dim.yac_symbol <- function(x) {
 #' @export
 length.yac_symbol <- function(x) {
   if (!(x$is_vec || x$is_mat)) {
-    return(NULL)
+    #return(NULL)
+    return(1L)
   }
   
   if (x$is_vec) {
@@ -109,6 +130,30 @@ length.yac_symbol <- function(x) {
   return(prod(dim(x)))
 }
 
+
+
+#' @export
+c.yac_symbol <- function(...) {
+  args <- list(...)
+
+  for (i in seq_along(args)) {
+    if (!is(args[[i]], "yac_symbol")) {
+      args[[i]] <- ysym(args[[i]])
+    }
+  }
+  
+  elements <- lapply(args, function(x) {
+    x$yacas_cmd
+  })
+  
+  cmd <- paste0("{", paste0(elements, collapse = ", "), "}")
+  
+  v <- ysym(cmd)
+  
+  return(v)
+}
+
+
 #' Simplify expression
 #' 
 #' @param x A `yac_symbol`
@@ -126,7 +171,7 @@ simplify <- function(x, timeout = 2) {
 simplify.yac_symbol <- function(x, timeout = 2) {
   stopifnot(is.null(timeout) || (!is.null(timeout) && timeout > 0))
   
-  x_res <- yac_symbol(yac_str(x$yacas_cmd))
+  x_res <- ysym(yac_str(x$yacas_cmd))
   z <- y_fn(x_res$yacas_cmd, "Simplify")
   
   z_res <- NULL
@@ -140,7 +185,7 @@ simplify.yac_symbol <- function(x, timeout = 2) {
   
   stopifnot(!is.null(z_res))
   
-  v <- yac_symbol(z_res)
+  v <- ysym(z_res)
   
   return(v)
 }
@@ -158,7 +203,7 @@ tex <- function(x) {
 
 #' @export
 tex.yac_symbol <- function(x) {
-  x_res <- yac_symbol(yac_str(x$yacas_cmd))
+  x_res <- ysym(yac_str(x$yacas_cmd))
   
   z <- y_fn(x_res$yacas_cmd, "TeXForm")
   z_res <- yac_str(z)
@@ -188,13 +233,13 @@ tex.yac_symbol <- function(x) {
   stopifnot(methods::is(x, "yac_symbol"))
   stopifnot(methods::is(y, "yac_symbol"))
   
-  x_res <- yac_symbol(yac_str(x$yacas_cmd))
-  y_res <- yac_symbol(yac_str(y$yacas_cmd))
+  x_res <- ysym(yac_str(x$yacas_cmd))
+  y_res <- ysym(yac_str(y$yacas_cmd))
   
   z <- paste0(x_res$yacas_cmd, " * ", y_res$yacas_cmd)
   z_res <- yac_str(z)
   
-  v <- yac_symbol(z_res)
+  v <- ysym(z_res)
   
   return(v)
 }
@@ -223,13 +268,13 @@ diag.yac_symbol <- function(x, ...) {
   stopifnot(methods::is(x, "yac_symbol"))
   
   y_res <- yac_str(x$yacas_cmd)
-  y <- yac_symbol(y_res)
+  y <- ysym(y_res)
   
   stopifnot(y$is_mat)
   
   w <- as_r(y$yacas_cmd)
   z <- base::diag(w, ...)
-  v <- yac_symbol(as_y(z))
+  v <- ysym(as_y(z))
   
   return(v)
 }
@@ -261,14 +306,14 @@ diag.yac_symbol <- function(x, ...) {
   stopifnot(methods::is(x, "yac_symbol"))
 
   y_res <- yac_str(x$yacas_cmd)
-  y <- yac_symbol(y_res)
+  y <- ysym(y_res)
   stopifnot(y$is_mat)
 
   w <- as_r(y$yacas_cmd)
   
   z <- base::`diag<-`(w, value)
   
-  v <- yac_symbol(as_y(z))
+  v <- ysym(as_y(z))
   
   return(v)
 }
@@ -297,7 +342,7 @@ upper.tri.yac_symbol <- function(x, diag = FALSE) {
   stopifnot(methods::is(x, "yac_symbol"))
   
   y_res <- yac_str(x$yacas_cmd)
-  y <- yac_symbol(y_res)
+  y <- ysym(y_res)
   
   stopifnot(y$is_mat)
   
@@ -328,7 +373,7 @@ lower.tri.yac_symbol <- function(x, diag = FALSE) {
   stopifnot(methods::is(x, "yac_symbol"))
   
   y_res <- yac_str(x$yacas_cmd)
-  y <- yac_symbol(y_res)
+  y <- ysym(y_res)
   
   stopifnot(y$is_mat)
   
@@ -348,12 +393,12 @@ lower.tri.yac_symbol <- function(x, diag = FALSE) {
 t.yac_symbol <- function(x) {
   # To see if x is indeed a matrix
   y_res <- yac_str(x$yacas_cmd)
-  y <- yac_symbol(y_res)
+  y <- ysym(y_res)
   
   stopifnot(y$is_mat)
   
   z <- y_fn(x = y_res, fn = "Transpose")
-  v <- yac_symbol(yac_str(z))
+  v <- ysym(yac_str(z))
   
   return(v)
 }
@@ -363,7 +408,7 @@ solve_yac_symbol_matrixinverse <- function(a) {
   
   z <- y_fn(x = a, fn = "Inverse")
   z_res <- yac_str(z)
-  v <- yac_symbol(z_res)
+  v <- ysym(z_res)
   
   return(v)
 }
@@ -375,7 +420,7 @@ solve_yac_symbol_linearsolve <- function(a, b) {
   stopifnot(nrow(a) == length(b))
   
   cmd <- paste0("SolveMatrix(", a$yacas_cmd, ", ", b$yacas_cmd, ")")
-  v <- yac_symbol(cmd)
+  v <- ysym(cmd)
   
   return(v)
 }
@@ -395,6 +440,8 @@ solve_yac_symbol_linearsolve <- function(a, b) {
 #' * `solve(a, b)`: find roots of `a` for variable `b`, i.e. yacas `Solve(a == 0, b)`
 #' * `solve(a, b, v)`: find solutions to `a == b` for variable `v`, i.e. yacas `Solve(a == b, v)`
 #' 
+#' This also works for a system of equations (when `a` is a vector)
+#' 
 #' @param a A `yac_symbol` 
 #' @param b A `yac_symbol` or a value, see details and examples.
 #' @param \dots See details and examples.
@@ -402,14 +449,14 @@ solve_yac_symbol_linearsolve <- function(a, b) {
 #' @examples 
 #' A <- outer(0:3, 1:4, "-") + diag(2:5)
 #' a <- 1:4
-#' B <- yac_symbol(A)
-#' b <- yac_symbol(a)
+#' B <- ysym(A)
+#' b <- ysym(a)
 #' solve(A)
 #' solve(B)
 #' solve(A, a)
 #' solve(B, b)
 #' 
-#' poly <- yac_symbol("x^2 - x - 6")
+#' poly <- ysym("x^2 - x - 6")
 #' solve(poly, "x")    # Solve(poly == 0, x)
 #' solve(poly, 3, "x") # Solve(poly == 3, x)
 #' 
@@ -435,14 +482,55 @@ solve.yac_symbol <- function(a, b, ...) {
   } else {
     # b also given:
     
-    if (a$is_mat && b$is_vec) {
+    if (a$is_mat) {
       if (!is(b, "yac_symbol")) {
         stop("'b' must be a yac_symbol.")
       }
+      if (!b$is_vec) {
+        stop("'b' must be a vector")
+      }
       
       return(solve_yac_symbol_linearsolve(a, b))
     }
     
+    # System of equations
+    if (!a$is_mat && a$is_vec) {
+      dots <- list(...)
+      
+      n <- length(a)
+      
+      b_yac <- if (is(b, "yac_symbol")) {
+        b$yacas_cmd
+      } else {
+        paste0("{", paste0(b, collapse = ", "), "}")
+      }
+
+      rhs <- if (length(dots) == 0L) {
+        paste0("{", paste0(rep("0", n), collapse = ", "), "}")
+      } else {
+        if (length(b) != n) {
+          stop("Unequal number of LHSs and RHSs")
+        }
+        b_yac
+      } 
+      
+      vars <- if (length(dots) == 0L) {
+        b_yac
+      } else {
+        v <- unlist(dots)
+        paste0("{", paste0(v, collapse = ", "), "}")
+      }
+      
+      eqs_lhs <- y_hlp_from_yacvec(a$yacas_cmd)
+      eqs_rhs <- y_hlp_from_yacvec(rhs)
+      stopifnot(length(eqs_lhs) == length(eqs_rhs))
+      eqs <- paste0("{", paste0(eqs_lhs, "==", eqs_rhs, collapse = ", "), "}")
+
+      cmd <- paste0("Solve(", eqs, ", ", vars, ")")
+      res <- ysym(cmd)
+      return(res)
+    }
+    
     if (!a$is_mat && !a$is_vec) {
       dots <- list(...)
       
@@ -450,7 +538,7 @@ solve.yac_symbol <- function(a, b, ...) {
         if (is.character(b) && length(b) == 1L) {
           # Solve(a, b)
           cmd <- paste0("Solve(", a$yacas_cmd, ", ", b, ")")
-          res <- yac_symbol(cmd)
+          res <- ysym(cmd)
           return(res)
         }
       } else if (length(dots) == 1L) {
@@ -459,7 +547,7 @@ solve.yac_symbol <- function(a, b, ...) {
         if (is.character(v) && length(v) == 1L) {
           # Solve(a == b, v)
           cmd <- paste0("Solve(", a$yacas_cmd, " == ", b, ", ", v, ")")
-          res <- yac_symbol(cmd)
+          res <- ysym(cmd)
           return(res)
         }
       } 
@@ -481,7 +569,7 @@ solve.yac_symbol <- function(a, b, ...) {
   stopifnot(methods::is(x, "yac_symbol"))
   
   y_res <- yac_str(x$yacas_cmd)
-  y <- yac_symbol(y_res)
+  y <- ysym(y_res)
   
   stopifnot(y$is_mat | y$is_vec)
   
@@ -511,7 +599,7 @@ solve.yac_symbol <- function(a, b, ...) {
   }
   
   stopifnot(!is.null(z))
-  v <- yac_symbol(as_y(z))
+  v <- ysym(as_y(z))
   
   return(v)
 }
@@ -533,7 +621,7 @@ solve.yac_symbol <- function(a, b, ...) {
   stopifnot(methods::is(x, "yac_symbol"))
   
   y_res <- yac_str(x$yacas_cmd)
-  y <- yac_symbol(y_res)
+  y <- ysym(y_res)
   
   stopifnot(y$is_mat | y$is_vec)
   
@@ -565,7 +653,7 @@ solve.yac_symbol <- function(a, b, ...) {
   }
   
   stopifnot(!is.null(z))
-  v <- yac_symbol(as_y(z))
+  v <- ysym(as_y(z))
   
   return(v)
 }
@@ -616,7 +704,7 @@ str.yac_symbol <- function(object, ...) {
 y_rmvars.yac_symbol <- function(x) {
   # FIXME: Best API?
   y <- y_rmvars(x$yacas_cmd)
-  v <- yac_symbol(y)
+  v <- ysym(y)
   
   return(v)
 }
@@ -632,19 +720,32 @@ Ops.yac_symbol = function(e1, e2) {
     stop("Function '", .Generic, "' not yet implemented for yac_symbol")
   } 
   
+  if (missing(e2)) {
+    if (.Method[1] == "") {
+      e1 <- ysym(e1)
+    }
+    
+    txt <- paste0(.Generic, "(", e1$yacas_cmd, ")")
+    txt_res <- yac_str(txt)
+    x <- ysym(txt_res)
+    return(x)
+  }
+  
+  # Both e1 and e2 given:
+  
   # LHS constant, e.g. 2*x: e1 is a number 2
   if (.Method[1] == "") {
-    e1 <- yac_symbol(e1)
+    e1 <- ysym(e1)
   }
   
   # RHS constant, e.g. x*2: e2 is a number 2
   if (.Method[2] == "") {
-    e2 <- yac_symbol(e2)
+    e2 <- ysym(e2)
   }
   
   txt <- paste0("(", e1$yacas_cmd, ")", .Generic, "(", e2$yacas_cmd, ")")
   txt_res <- yac_str(txt)
-  x <- yac_symbol(txt_res)
+  x <- ysym(txt_res)
   
   return(x)
 }
@@ -685,7 +786,7 @@ Math.yac_symbol = function(x, ...) {
   fn <- Math_transtab[i, 2L]
   
   txt <- paste0(fn, "(", x$yacas_cmd, ")")
-  x <- yac_symbol(txt)
+  x <- ysym(txt)
   return(x)
 }
 
@@ -705,7 +806,7 @@ deriv.yac_symbol <- function(expr, ...) {
     paste0("(D(", var, ") ", expr$yacas_cmd, ")")
   }))
   
-  res_sym <- yac_symbol(res)
+  res_sym <- ysym(res)
   
   return(res_sym)
 }
@@ -729,7 +830,7 @@ Jacobian.yac_symbol <- function(expr, ...) {
   res <- paste0("JacobianMatrix( ", expr$yacas_cmd, ", {", 
                 paste0(vars, collapse = ", "), "})")
   
-  res_sym <- yac_symbol(res)
+  res_sym <- ysym(res)
   return(res_sym)
 }
 
@@ -752,7 +853,7 @@ Hessian.yac_symbol <- function(expr, ...) {
   res <- paste0("HessianMatrix(", expr$yacas_cmd, ", {", 
                 paste0(vars, collapse = ", "), "})")
   
-  res_sym <- yac_symbol(res)
+  res_sym <- ysym(res)
   return(res_sym)
 }
 
@@ -768,3 +869,152 @@ as.character.yac_symbol <- function(x, ...) {
   return(x$yacas_cmd)
 }
 
+
+
+
+
+
+
+bound_to_str <- function(b) {
+  if (is.infinite(b)) {
+    if (b > 0) {
+      return("Infinity")
+    } else {
+      return("-Infinity")
+    }
+  }
+  
+  if (is.character(b)) {
+    return(b)
+  }
+  
+  bnd <- deparse(eval(substitute(substitute(b)), parent.frame()))
+  bnd <- gsub("pi", "Pi", bnd, fixed = TRUE)
+  
+  return(bnd)
+}
+
+
+
+
+#' Integration of Functions
+#' 
+#' If `f` is a `yac_symbol`, `yacas`'s `Integrate()` is used. 
+#' Else, [stats::integrate()] is used.
+#' 
+#' Additional arguments:
+#' 
+#' * [`yac_symbol`]: `var`, `lower`, `upper`
+#' * Else ([stats::integrate()]): `lower`, `upper`
+#' 
+#' @param f Function to integrate. See details.
+#' @param \dots See details.
+#' 
+#' @concept yac_symbol
+#' 
+#' @export
+integrate <- function(f, ...) {
+  UseMethod("integrate")
+}
+
+#' @importFrom stats integrate
+#' @export
+integrate.default <- function(...) {
+  x <- stats::integrate(...)
+  return(x)
+}
+
+#' @export
+integrate.yac_symbol <- function(f, var, lower, upper, ...) {
+  cmd <- if (missing(lower) && missing(upper)) {
+    paste0("Integrate(", var, ")")
+  } else {
+    lwr_str <- bound_to_str(lower)
+    upr_str <- bound_to_str(upper)
+    paste0("Integrate(", var, ", ", lwr_str, ", ", upr_str, ")")
+  }
+  
+  z <- paste0(cmd, f$yacas_cmd)
+  z_res <- yac_str(z)
+  
+  v <- ysym(z_res)
+  
+  return(v)
+}
+
+
+
+#' Summation
+#' 
+#' Sums `expr` by letting `var` taking values 
+#' from `lower` to `upper` (potentially `Inf`)
+#' 
+#' @param expr Expression to be summed
+#' @param var Variable to sum
+#' @param lower Lower limit
+#' @param upper Upper limit
+#' @param \dots Not used
+#' @param na.rm Not used
+#' 
+#' @concept yac_symbol
+#' 
+#' @export
+sum.yac_symbol <- function(expr, var, lower, upper, ..., na.rm = FALSE) {
+  lwr_str <- bound_to_str(lower)
+  upr_str <- bound_to_str(upper)
+  
+  cmd <- paste0("Sum(", var, ", ", lwr_str, ", ", upr_str, ", ", expr$yacas_cmd, ")")
+  z_res <- yac_str(cmd)
+  
+  v <- ysym(z_res)
+  
+  return(v)
+}
+
+
+
+
+#' Limits
+#' 
+#' If first argument is a `yac_symbol`, `yacas`'s `Limit()` is used. 
+#' 
+#' Arguments:
+#' 
+#' * [`yac_symbol`]: `f`, `var`, `val`, `from_left`, `from_right`
+#' 
+#' @param \dots See details.
+#' 
+#' @concept yac_symbol
+#' 
+#' @export
+lim <- function(...) {
+  UseMethod("lim")
+}
+
+#' @export
+lim.default <- function(...) {
+  stop("Not implemented for anything else than yac_symbol's created with ysym()")
+}
+
+#' @export
+lim.yac_symbol <- function(f, var, val, ...) {
+  dots <- list(...)
+  
+  val_str <- bound_to_str(val)
+
+  cmd_add <- if (!is.null(dots$from_left) && length(dots$from_left) == 1L && dots$from_left == TRUE) {
+    ", Left"
+  } else if (!is.null(dots$from_right) && length(dots$from_right) == 1L && dots$from_right == TRUE) {
+    ", Right"
+  } else {
+    ""
+  }
+  
+  cmd <- paste0("Limit(", var, ", ", val_str, cmd_add, ") (", f$yacas_cmd, ")")
+  
+  z_res <- yac_str(cmd)
+  
+  v <- ysym(z_res)
+  
+  return(v)
+}
