@@ -2,7 +2,19 @@ context("Ryacas symbol")
 
 ##############################
 
+test_that("Basics", {
+  x <- "x+x+x"
+  xs <- ysym(x)
+  expect_equal(as_r(xs), expression(3*x))
+  expect_equal(as_y(xs), "3*x")
+})
+
+##############################
+
 test_that("dim()/length()", {
+  x <- ysym("x")
+  expect_equal(length(x), 1L)
+  
   for (nrow in 1:4) {
     info <- paste0("length = ", nrow)
     vec <- integer(nrow)
@@ -15,21 +27,34 @@ test_that("dim()/length()", {
       mat <- matrix(0, nrow = nrow, ncol = ncol)
       expect_equal(dim(mat), c(nrow, ncol), info = info)
       
-      B <- yac_symbol(mat)
+      B <- ysym(mat)
       expect_equal(dim(B), dim(mat), info = info)
       expect_equal(length(B), length(mat), info = info)
     }
   }
 })
 
+
+
+test_that("c()", {
+  x <- ysym("x")
+  y <- ysym("y")
+  z <- c(x, y)
+  expect_equal(length(z), length(x) + length(y))
+  
+  z <- c(2*x, -y)
+  expect_equal(as.character(z), "{2*x,-y}")
+  expect_equal(as_r(z), expression(c(2 * x, -y)))
+})
+
 ##############################
 
 A <- matrix(1:16, nrow = 4, ncol = 4)
 a <- 1:4
 
-test_that("yac_symbol()", {
-  B <- yac_symbol(A)
-  b <- yac_symbol(a)
+test_that("ysym()", {
+  B <- ysym(A)
+  b <- ysym(a)
 
   expect_s3_class(B, "yac_symbol")
   expect_s3_class(b, "yac_symbol")
@@ -43,8 +68,8 @@ test_that("yac_symbol()", {
   expect_equal(eval(yac_expr(x)), c(A %*% a))
 })
 
-B <- yac_symbol(A)
-b <- yac_symbol(a)
+B <- ysym(A)
+b <- ysym(a)
 
 test_that("yac_str()", {
   expect_equal(yac_str(B), gsub(" ", "", as_y(A), fixed = TRUE))
@@ -74,13 +99,13 @@ test_that("as_r", {
   
   # A1 <- A
   # A1[2, 2] <- "x"
-  # B1 <- yac_symbol(A1)
+  # B1 <- ysym(A1)
   # 
   # expect_equal(as_r(B1), A1)
   
   A1 <- A
   A1[2, 2] <- "x"
-  B1 <- yac_symbol(A1)
+  B1 <- ysym(A1)
   
   A2 <- A
   A2[2, 2] <- 999
@@ -160,12 +185,24 @@ test_that("solve()", {
   }
   
   A1 <- hilbert_r(4)
-  B1 <- yac_symbol(as_y(hilbert_y(4)))
+  B1 <- ysym(as_y(hilbert_y(4)))
 
   expect_equal(A1, as_r(B1))
   expect_equal(solve(A1), as_r(solve(B1)))
 })
 
+test_that("solve() for systems", {
+  # Rosenbrock
+  fs <- ysym("(1 - x)^2 + 100*(y - x^2)^2")
+  g <- deriv(fs, c("x", "y"))
+  sol <- solve(g, c("x", "y"))
+  sol_nn <- y_rmvars(sol)
+  expect_equal(dim(sol_nn), c(1, 2))
+  sol_nn_v <- sol_nn[1, ]
+  expect_equal(as.character(sol_nn_v), "{1,1}")
+  expect_equal(as_r(sol_nn_v), c(1, 1))
+})
+
 
 test_that("Getters for vectors", {
   expect_equal(ncol(a), nrow(a))
@@ -339,7 +376,7 @@ test_that("Setters for matrices", {
 })
 
 test_that("Derivatives", {
-  L <- yac_symbol("x^2 * (y/4) - a*(3*x + 3*y/2 - 45)")
+  L <- ysym("x^2 * (y/4) - a*(3*x + 3*y/2 - 45)")
   
   # derivative
   expect_equal(as.character(as_r(deriv(L, "x"))), 
@@ -354,7 +391,7 @@ test_that("Derivatives", {
                "rbind(c(y/2, x/2, -3), c(x/2, 0, -3/2), c(-3, -3/2, 0))")
   
   # Jacobian
-  L2 <- yac_symbol(c("x^2 * (y/4) - a*(3*x + 3*y/2 - 45)", 
+  L2 <- ysym(c("x^2 * (y/4) - a*(3*x + 3*y/2 - 45)", 
                      "x^3 + 4*a^2")) # just some function
   expect_equal(as.character(as_r(Jacobian(L2, "x"))), 
                "rbind(c((x * y)/2 - 3 * a), c(3 * x^2))")
@@ -370,7 +407,7 @@ test_that("solve linear system", {
   # ------------------------------------
   # Input validation
   # ------------------------------------
-  poly <- yac_symbol("x^2 - x - 6")
+  poly <- ysym("x^2 - x - 6")
   expect_error(solve(poly))
   
   # ------------------------------------
@@ -378,8 +415,8 @@ test_that("solve linear system", {
   # ------------------------------------
   A <- outer(0:3, 1:4, "-") + diag(2:5)
   a <- 1:4
-  B <- yac_symbol(A)
-  b <- yac_symbol(a)
+  B <- ysym(A)
+  b <- ysym(a)
   expect_equal(solve(A), as_r(solve(B)))
   
   # ------------------------------------
@@ -395,11 +432,11 @@ test_that("solve linear system", {
 test_that("solve (roots/others)", {
   A <- outer(0:3, 1:4, "-") + diag(2:5)
   a <- 1:4
-  B <- yac_symbol(A)
-  b <- yac_symbol(a)
+  B <- ysym(A)
+  b <- ysym(a)
 
   
-  poly <- yac_symbol("x^2 - x - 6")
+  poly <- ysym("x^2 - x - 6")
   expect_error(solve(poly))
   
   expect_error(solve(B, poly))
@@ -416,3 +453,52 @@ test_that("solve (roots/others)", {
   expect_equal(as_r(y_rmvars(solve(poly, 3, "x"))), c(3.54138126514911, -2.54138126514911))
 })
 
+
+
+test_that("integrate", {
+  res <- integrate(function(x) x^2, 0, 1)
+  expect_equal(res$value, 1/3)
+  
+  xs <- ysym("x")
+  f <- xs*log(xs)
+  res <- integrate(f, "x")
+  expect_equal(as.character(res), "(Ln(x)*x^2)/2-x^2/4")
+  expect_equal(eval(as_r(res), list(x = 1)), -0.25)
+})
+
+
+test_that("sum", {
+  res <- sum(1:10)
+  expect_equal(res, 55)
+  
+  xs <- ysym("x")
+  ks <- ysym("k")
+  res <- sum(xs^ks, "k", 0, "n")
+  expect_equal(as.character(res), "(1-x^(n+1))/(1-x)")
+  
+  res <- sum(1/ks^2, "k", 1, Inf)
+  expect_equal(as.character(res), "Pi^2/6")
+  expect_equal(as_r(res), pi^2/6)
+})
+
+test_that("sum", {
+  xs <- ysym("x")
+  
+  res <- lim(sin(xs)/xs, "x", 0)
+  expect_equal(as.character(res), "1")
+  
+  res <- lim((sin(xs)-tan(xs))/xs^3, "x", 0)
+  expect_equal(as.character(res), "(-1)/2")
+  
+  res <- lim(1/xs, "x", 0)
+  expect_equal(as.character(res), "Undefined")
+  expect_equal(as_r(res), NaN)
+  
+  res <- lim(1/xs, "x", 0, from_left = TRUE)
+  expect_equal(as.character(res), "-Infinity")
+  expect_equal(as_r(res), -Inf)
+  
+  res <- lim(1/xs, "x", 0, from_right = TRUE)
+  expect_equal(as.character(res), "Infinity")
+  expect_equal(as_r(res), Inf)
+})
